==> boost_1.31.0.orig.tar.gz: boost_1_31_0/boost/spirit.hpp <==
/*=============================================================================
    Spirit v1.7.0
    Copyright (c) 1998-2003 Joel de Guzman
    Copyright (c) 2001-2003 Daniel Nuffer
    Copyright (c) 2001-2003 Hartmut Kaiser
    Copyright (c) 2002-2003 Martin Wille
    Copyright (c) 2002 Juan Carlos Arevalo-Baeza
    Copyright (c) 2002 Raghavendra Satish
    Copyright (c) 2002 Jeff Westfahl
    Copyright (c) 2001 Bruce Florman
    Copyright (c) 2003 Giovanni Bajo
    Copyright (c) 2003 Vaclav Vesely
    Copyright (c) 2003 Jonathan de Halleux
    http://spirit.sourceforge.net/

    Use, modification and distribution is subject to the Boost Software
    License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
    http://www.boost.org/LICENSE_1_0.txt)
=============================================================================*/
#if !defined(SPIRIT_HPP)
#define SPIRIT_HPP

///////////////////////////////////////////////////////////////////////////////
//
//  If SPIRIT_DEBUG is defined, the following header includes the
//  Spirit.Debug layer, otherwise the non-debug Spirit.Core is included.
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/core.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.Meta
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/meta.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.ErrorHandling
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/error_handling.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.Iterators
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/iterator.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.Symbols
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/symbols.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.Utilities
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/utility.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.Attributes
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/attribute.hpp>

#endif // !defined(SPIRIT_HPP)

==> boost1.35_1.35.0.orig.tar.gz: boost_1_35_0/boost/spirit.hpp <==
/*=============================================================================
    Copyright (c) 1998-2003 Joel de Guzman
    Copyright (c) 2001-2003 Daniel Nuffer
    Copyright (c) 2001-2003 Hartmut Kaiser
    Copyright (c) 2002-2003 Martin Wille
    Copyright (c) 2002 Juan Carlos Arevalo-Baeza
    Copyright (c) 2002 Raghavendra Satish
    Copyright (c) 2002 Jeff Westfahl
    Copyright (c) 2001 Bruce Florman
    Copyright (c) 2003 Giovanni Bajo
    Copyright (c) 2003 Vaclav Vesely
    Copyright (c) 2003 Jonathan de Halleux
    http://spirit.sourceforge.net/
    http://www.boost.org/libs/spirit

    Use, modification and distribution is subject to the Boost Software
    License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
    http://www.boost.org/LICENSE_1_0.txt)

    See http://www.boost.org/libs/spirit for documentation
=============================================================================*/
#if !defined(SPIRIT_HPP)
#define SPIRIT_HPP

///////////////////////////////////////////////////////////////////////////////
//
//  If BOOST_SPIRIT_DEBUG is defined, the following header includes the
//  Spirit.Debug layer, otherwise the non-debug Spirit.Core is included.
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/core.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.Meta
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/meta.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.ErrorHandling
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/error_handling.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.Iterators
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/iterator.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.Symbols
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/symbols.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.Utilities
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/utility.hpp>

///////////////////////////////////////////////////////////////////////////////
//
//  Spirit.Attributes
//
///////////////////////////////////////////////////////////////////////////////
#include <boost/spirit/attribute.hpp>

#endif // !defined(SPIRIT_HPP)
